@@ -16,6 +16,7 @@
 #'   identifier-style names. Any number of layers and even different types of
 #'   layers (e.g. markers and polygons) can share the same group name.
 #' @param popup A column of \code{data} to be used as a popup.
+#' @param label A column of \code{data} to be used as a label.
 #' @param data A data frame. The data frame must contain the data to plot your
 #'   choice of openair directional analysis plot, which includes wind speed
 #'   (\code{ws}), wind direction (\code{wd}), and the column representing the
@@ -28,8 +29,6 @@
 #'   [openair::windRose()].
 #' @param pollutant The name of the pollutant to be plot. Note that, if
 #'   \code{fun = openair::windRose}, you must set \code{pollutant = "ws"}.
-#' @param type The grouping variable that provides a data set for a specific
-#'   location. Often, with several sites, \code{type = "site"} is used.
 #' @param iconWidth The actual width of the plot on the map in pixels.
 #' @param iconHeight The actual height of the plot on the map in pixels.
 #' @param fig.width The width of the plots to be produced in inches.
@@ -37,10 +36,6 @@
 #' @param ... Other arguments for the plotting function (e.g. \code{period} for
 #'   [openair::polarAnnulus()]).
 #' @return A leaflet object.
-#' @import leaflet
-#' @importFrom rlang .data
-#' @importFrom grDevices dev.off png
-#' @importFrom stats na.omit
 #' @export
 #'
 #' @examples
@@ -55,7 +50,6 @@
 #'     lat = "latitude",
 #'     lng = "longitude",
 #'     pollutant = "ws",
-#'     type = "site",
 #'     fun = windRose,
 #'     group = "Wind Rose"
 #'   ) %>%
@@ -63,7 +57,7 @@
 #'     data = polar_data,
 #'     lat = "latitude",
 #'     lng = "longitude",
-#'     type = "site",
+#'     pollutant = "nox",
 #'     group = "Polar Plot"
 #'   ) %>%
 #'   addLayersControl(
@@ -71,97 +65,112 @@
 #'   )
 #' }
 #'
-addPolarMarkers <- function(map, lng = NULL, lat = NULL, layerId = NULL, group = NULL, popup,
-                            data, fun = openair::polarPlot, pollutant = "nox", type = "default",
-                            iconWidth = 200, iconHeight = 200, fig.width = 4, fig.height = 4,
-                            ...) {
-  . <- NULL
+addPolarMarkers <-
+  function(map,
+           lng = NULL,
+           lat = NULL,
+           layerId = NULL,
+           group = NULL,
+           popup = NULL,
+           label = NULL,
+           data,
+           fun = openair::polarPlot,
+           pollutant,
+           iconWidth = 200,
+           iconHeight = 200,
+           fig.width = 4,
+           fig.height = 4,
+           ...) {
+    # guess lat/lon
+    latlon <- assume_latlon(
+      data = data,
+      latitude = lat,
+      longitude = lng
+    )
+    lat <- latlon$latitude
+    lng <- latlon$longitude
 
-  if (type == "default") {
-    data <- dplyr::mutate(data, type = "default")
-  }
-
-  if (missing(popup)) popup <- type
-
-  # define plotting function
-  args <- list(...)
-  thefun <- function(...) {
-    rlang::exec(fun, !!!args, ...)
-  }
-
-  # where to write files
-  icon_dir <- tempdir()
-
-  save_icon <-
-    function(data,
-             fun,
-             dir,
-             pollutant,
-             fig.width,
-             fig.height,
-             ...) {
-      png(
-        filename = paste0(dir, "/", data[[type]][1], "_", pollutant, ".png"),
-        width = fig.width * 300,
-        height = fig.height * 300,
-        res = 300,
-        bg = "transparent"
-      )
-
-      plt <- fun(
-        data,
-        key = FALSE,
-        pollutant = pollutant,
-        par.settings = list(axis.line = list(col = "transparent")),
-        # ...
-      )
-
-      dev.off()
+    # define plotting function
+    args <- list(...)
+    thefun <- function(...) {
+      rlang::exec(fun, !!!args, ..., annotate = FALSE)
     }
 
-  # go through all sites and make some plot
-  data %>%
-    dplyr::group_split(dplyr::across(dplyr::all_of(type))) %>%
-    purrr::walk(
-      .f = ~ save_icon(
-        data = .x,
-        fun = thefun,
-        dir = icon_dir,
-        pollutant = pollutant,
-        fig.width = fig.width,
-        fig.height = fig.height,
-        # ...
+    # where to write files
+    icon_dir <- tempdir()
+
+    save_icon <-
+      function(data,
+               fun,
+               dir,
+               pollutant,
+               fig.width,
+               fig.height,
+               ...) {
+        grDevices::png(
+          filename = paste0(dir, "/", data[[lat]][1], data[[lng]][1], "_", pollutant, ".png"),
+          width = fig.width * 300,
+          height = fig.height * 300,
+          res = 300,
+          bg = "transparent"
+        )
+
+        plt <- fun(
+          data,
+          key = FALSE,
+          pollutant = pollutant,
+          par.settings = list(axis.line = list(col = "transparent"))
+        )
+
+        grDevices::dev.off()
+      }
+
+    # go through all sites and make some plot
+    data %>%
+      dplyr::group_split(.data[[lat]], .data[[lng]]) %>%
+      purrr::walk(
+        .f = ~ save_icon(
+          data = .x,
+          fun = thefun,
+          dir = icon_dir,
+          pollutant = pollutant,
+          fig.width = fig.width,
+          fig.height = fig.height
+        )
       )
+
+    # definition of 'icons' aka the openair plots
+    leafIcons <-
+      lapply(sort(paste0(
+        icon_dir, "/", unique(data[[lat]]), unique(data[[lng]]), "_", pollutant, ".png"
+      )),
+      leaflet::makeIcon,
+      iconWidth = iconWidth,
+      iconHeight = iconHeight
+      )
+
+    names(leafIcons) <- paste0(unique(data[[lat]]), unique(data[[lng]]))
+    class(leafIcons) <- "leaflet_icon_set"
+
+    plot_data <-
+      dplyr::group_by(data, .data[[lat]], .data[[lng]]) %>%
+      dplyr::slice(n = 1) %>%
+      dplyr::arrange(.data[[lat]], .data[[lng]])
+
+    if (!is.null(label)) label <- plot_data[[label]]
+    if (!is.null(popup)) popup <- plot_data[[popup]]
+
+    map <- leaflet::addMarkers(
+      map,
+      data = plot_data,
+      lng = plot_data[[lng]],
+      lat = plot_data[[lat]],
+      icon = leafIcons,
+      popup = popup,
+      label = label,
+      group = group,
+      layerId = layerId
     )
 
-  # definition of 'icons' aka the openair plots
-  leafIcons <-
-    lapply(sort(paste0(
-      icon_dir, "/", unique(data[[type]]), "_", pollutant, ".png"
-    )),
-    leaflet::makeIcon,
-    iconWidth = iconWidth,
-    iconHeight = iconHeight
-    )
-
-  names(leafIcons) <- unique(data[[type]])
-  class(leafIcons) <- "leaflet_icon_set"
-
-  plot_data <-
-    dplyr::group_by(data, .data[[type]]) %>%
-    dplyr::slice(n = 1) %>%
-    dplyr::arrange(.data[[type]])
-
-  map <- leaflet::addMarkers(
-    map,
-    data = plot_data,
-    lng = plot_data[[lng]],
-    lat = plot_data[[lat]],
-    icon = leafIcons,
-    popup = plot_data[[type]],
-    group = group,
-    layerId = layerId
-  )
-
-  map
-}
+    map
+  }
