@@ -84,7 +84,7 @@ checkMapPrep <-
       if (wd %in% Names & is.numeric(mydata[, wd])) {
         ## check for wd <0 or > 360
         if (any(sign(mydata[[wd]][!is.na(mydata[[wd]])]) == -1 |
-          mydata[[wd]][!is.na(mydata[[wd]])] > 360)) {
+                mydata[[wd]][!is.na(mydata[[wd]])] > 360)) {
           warning("Wind direction < 0 or > 360; removing these data")
           mydata[[wd]][mydata[[wd]] < 0] <- NA
           mydata[[wd]][mydata[[wd]] > 360] <- NA
@@ -322,7 +322,7 @@ makeMap <-
     plot_data <-
       data %>%
       dplyr::group_by(.data[[latitude]], .data[[longitude]], .data[[split_col]]) %>%
-      dplyr::mutate(dc = mean(!is.na(.data[[split_col]]))) %>%
+      dplyr::mutate(dc = mean(!is.na(.data[["conc"]]))) %>%
       dplyr::ungroup() %>%
       dplyr::distinct(.data[[latitude]], .data[[longitude]], .data[[split_col]], .keep_all = TRUE) %>%
       dplyr::arrange(.data[[latitude]], .data[[longitude]])
@@ -380,11 +380,11 @@ makeMap <-
         )
     } else if (length(icons) > 1 & length(provider) == 1) {
       m <- leaflet::addLayersControl(m,
-        baseGroups = names(icons) %>% purrr::map_chr(quickTextHTML)
+                                     baseGroups = names(icons) %>% purrr::map_chr(quickTextHTML)
       )
     } else if (length(provider) > 1 & length(icons) == 1) {
       m <- leaflet::addLayersControl(m,
-        baseGroups = provider
+                                     baseGroups = provider
       )
     }
 
@@ -416,7 +416,7 @@ assume_latlon <- function(data, latitude, longitude) {
     len <- length(out)
     if (len > 1) {
       cli::cli_abort("Cannot identify {name}: Multiple possible matches ({out})",
-        call = NULL
+                     call = NULL
       )
       return(NULL)
     } else if (len == 0) {
